@@ -20,6 +20,7 @@
 #include <fstream>
 #include <vector>
 
+#include <assert.h>
 #include <string.h>
 #include <getopt.h>
 
@@ -51,9 +52,9 @@ int __STACK_DEBUG__ = 0;
 
 using namespace std;
 
-static char* program_name = "readhead-list";
-static char* program_header = "$Header: /var/cvsroot/infrastructure/readahead-list/src/filelist-order.cxx,v 1.4 2005/03/28 09:36:35 robbat2 Exp $";
-static char* program_id = "$Id: filelist-order.cxx,v 1.4 2005/03/28 09:36:35 robbat2 Exp $";
+static char* program_name = "filelist-order";
+static char* program_header = "$Header: /var/cvsroot/infrastructure/readahead-list/src/filelist-order.cxx,v 1.6 2005/05/17 02:12:43 robbat2 Exp $";
+static char* program_id = "$Id: filelist-order.cxx,v 1.6 2005/05/17 02:12:43 robbat2 Exp $";
 
 static int flag_input_file = 0;
 static int flag_input_stdin = 0;
